@@ -7,7 +7,7 @@ package Debian::Debhelper::Buildsystem::pd_lib_builder;
 
 use strict;
 use warnings;
-use Debian::Debhelper::Dh_Lib qw(compat dpkg_architecture_value is_cross_compiling);
+use Debian::Debhelper::Dh_Lib qw(compat);
 use Dpkg::Version qw();
 
 use parent qw(Debian::Debhelper::Buildsystem::makefile);
@@ -24,6 +24,10 @@ sub new {
     return $this;
 }
 
+sub _should_inject_cross_build_tools {
+    return 1;
+}
+
 sub check_auto_buildable {
     # pd-lib-builder can be enabled if there is a makefile
     # that calls 'include $(PDLIBBUILDER_DIR)/Makefile.pdlibbuilder'
@@ -60,23 +64,6 @@ sub build {
     # also override CPPFLAGS, CFLAGS, LDFLAGS
     # and arch.c.flags (which contains optimization flags that exceed our baseline)
     my $this=shift;
-    if (is_cross_compiling()) {
-        # Inject build tools variables during cross-compile
-        # this should really be fixed in debhelper...see #1024296
-        my %DEB_DEFAULT_TOOLS = (
-            'CC'		=> 'gcc',
-            'CXX'		=> 'g++',
-            'PKG_CONFIG'	=> 'pkg-config',
-            );
-        for my $var (sort(keys(%DEB_DEFAULT_TOOLS))) {
-            my $tool = $DEB_DEFAULT_TOOLS{$var};
-            if ($ENV{$var}) {
-                unshift @_, $var . "=" . $ENV{$var};
-            } else {
-                unshift @_, $var . "=" . dpkg_architecture_value("DEB_HOST_GNU_TYPE") . "-" . $tool;
-            }
-        }
-    }
 
     unshift(@_, "PDLIBBUILDER_DIR=/usr/share/pd-lib-builder/");
     unshift(@_, "CPPFLAGS=$ENV{CPPFLAGS}");
